import { Options } from 'upembed-plyr';

interface IOptions extends Options{
  /**
   * Banner Interactions Options
   */
  banner?: {
    enabled: boolean;
    text: string;
    startTime: number;
    endTime?: number;
    buttonText: string;
    buttonUrl: string;
    position?: 'left' | 'right' | 'center';
    backgroundColor?: string;
    textColor?: string;
    buttonBackgroundColor?: string;
    buttonTextColor?: string;
  }

  fullscreen?: {
    enabled: boolean;
    startTime: number;

    title: string;
    description: string;
    buttonText: string;
    buttonUrl: string;
    linkText: string;
    linkUrl: string;

    backgroundColor?: string;
    textColor?: string;
    buttonBackgroundColor?: string;
    buttonTextColor?: string;

    linkColor?: string;
  },

  leadGen?: {
    enabled: boolean;
    skipable: boolean;
    startTime: number;

    formTitle: string;
    formDescription?: string;
    formFields: IFormField[];
    submitButtonText: string;
    formAction: string;

    backgroundColor?: string;
    textColor?: string;
    buttonBackgroundColor?: string;
    buttonTextColor?: string;
  },

  customWidget?: {
    enabled: boolean;
    startTime: number;
    html: string;
    backgroundColor?: string;
  },

  annotations?: {
    enabled: boolean;
    cards: IAnnotation[];
  }
}

interface IAnnotation {
  startTime: number;
  endTime?: number;
  text: string;
  url: string;
  position: 'left' | 'right';
  variant?: 'light' | 'dark';
}

interface IFormField {
  name: string;
  label: string;
  type: 'text' | 'email' | 'tel' | 'textarea' | 'number'
  required: boolean;
}

interface IStateValue {
  visible: boolean;
  completed: boolean;
  pausedWhenVisible: boolean;
}

interface IAnnotationStateValue {
  visible: boolean;
  completed: boolean;
  index: number;
}

type TElement = 'banner' | 'fullscreen' | 'leadGen' | 'customWidget';

interface IFormStyle {
  buttonBackground: string;
  buttonColor: string;
  fieldBackground: string;
  fieldColor: string;
}

export { IAnnotation, IAnnotationStateValue, IFormField, IFormStyle, IOptions, IStateValue, TElement };
